"""
Returns a full-featured HTML tag for an e-mail anchor including JavaScript.
Deliberate obfucation is applied to the address and everything else that
spambots typically target.

Takes four arguments:

  address:      The e-mail address to be obsfucated

  name:         The name to go along with that e-mail address

  subject/rel:  For <a>nchors, the subject of the message.
                For <link>s, the rel attribute.

  content/flag: Normally, this is the content of the tag.
                It can hold the following sentinels, however:

                  None             just obsfucate the e-mail
                                   address itself.

                 'mailto:'         just obsfucate the e-mail
                                   address with a 'mailto:'
                                   prefix and optional suffix.

                 'HTML link'       create a link tag rather
                                   than an anchor.

                 'E-Mail Graphic'  creates a full anchor with
                                   a graphic
  
"""

version='1.0'

# these three variables should probably be modified for your site

statusMsgDefault='Saugus.net'
addressDefault='webmaster@saugus.net'
graphicURL='/Icons/Extras/mail.gif'

from Products.PythonScripts.standard import html_quote

# The obsfucate function is the heart of this little script.  It
# performs a simple ord-type "encryption" that is both simple enough
# for browsers to handle without difficulty and complex enough to
# foil stupid spambots.

def obsfucate(inStr):
  """Converts characters of input to HTML entity form to confuse spambots."""
  outStr=""
  for eachChar in inStr:
    outStr += "&#%d;" % (ord(eachChar))
  return outStr

# This script will check for the default_status_msg property to provide
# some on-the-fly customization.  It basically uses it within the little
# JavaScript snippet to provide a status message for the onmouseout
# condition.  If it doesn't exist, the script will just use the default
# provided above.

if _.has_key('default_status_msg'):
  statusMsg=_.getitem('default_status_msg',1)
else:
  statusMsg=statusMsgDefault

# The name is used here to build an onmouseover JavaScript event.  If it
# isn't provided, a basic default is used instead.

if name:
  activeMsg='E-mail '+name
else:
  activeMsg='Send e-mail'

# The address is prepared for obsfucation.  If it isn't provided, the
# default provided above is used instead.

if not address:
  address=addressDefault
else:
  address=address.lower()

# An e-mail subject is created as desired (remembering the proper HTML
# quoting, of course).

if subject:
  subjectLine='?subject='+html_quote(subject)
else:
  subjectLine=''

# If content is None, we're only obsfucating the e-mail address itself.
# Any other arguments are ignored.  This is useful for including an
# e-mail address without a link (for whatever reason) on a web page, or
# for build-your-own sorts of tags.

if not content:
  # just encrypts the address, nothing else
  print '%s' % (obsfucate(address))

# If content is 'mailto', we're only obsfucating the e-mail address
# itself with a 'mailto:' prefix and an optional subject.  Any other
# arguments are ignored.  This is primarily useful for build-your-own
# sorts of tags.

elif content=='mailto:':
  # just encrypts the address with a mailto: prefix
  print '%s' % (obsfucate('mailto:'+address+subjectLine))

# If content is 'HTML link', we're building a W3C compliant <link>
# element to be used in the <head> portion of the web page.  The only
# drawback is that some browsers expect a rel attribute of "Author"
# while some expect a rel attribute of "Made".  Unfortunately the W3C
# doesn't really help much here, as the current HTML spec doesn't
# mention either one and different earlier versions suggested one or
# the other at different times...  Whichever one you choose, you put
# it in the subject variable.

elif content=='HTML link':
  # returns a full <link> tag using the name as the rel attribute
  print '<link rel="%s" title="%s..." href="%s" />' % (name,subject,obsfucate('mailto:'+address))

# If content is 'E-Mail Graphic', we're building a little graphic
# with an e-mail link.  The graphic definition comes from the default
# one provided above, and the address, subject, and status message
# are all as built / prepped above.

elif content=='E-Mail Graphic':
  # returns a full <a>nchor tag using a simple graphic for content
  print '<a href="%s" title="%s"' % (obsfucate('mailto:'+address+subjectLine),obsfucate(subject))
  print '''onmouseover="window.status='%s...';return true"''' % (obsfucate(activeMsg))
  print '''onmouseout="window.status='%s';return true"><img''' % (statusMsg)
  print '''src="%s" width="23" height="23"''' % (graphicURL)
  print '''border="0" alt="e-mail:" /></a>'''

# For all other cases we're building a typical textual anchor with
# address, subject, and status message as built / prepped above, and
# content being the (surprise!) content.

else:
  # returns a full <a>nchor tag using all the arguments normally
  print '<a href="%s%s" title="%s"' % (obsfucate('mailto:'+address),obsfucate(subjectLine),obsfucate(subject))
  print '''onmouseover="window.status='%s...';return true"''' % (obsfucate(activeMsg))
  print '''onmouseout="window.status='%s';return true">%s</a>''' % (statusMsg,obsfucate(content))

return printed
